<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        title="提交反馈"
        width="500px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="77px" >
        <el-form-item label="企业名:" prop="name" >
          <span>{{ state.form.companyName }}</span>
        </el-form-item>
<!--        <el-row :gutter="12">-->
<!--          <el-col :span="10">-->
<!--            <el-form-item label="仓库:" prop="name" >-->
<!--              <span>{{ state.form.companyName }}</span>-->
<!--            </el-form-item>-->
<!--          </el-col>-->
<!--          <el-col :span="12">-->
<!--            <el-form-item label="库房:" prop="name" >-->
<!--              <span>{{ state.form.companyName }}</span>-->
<!--            </el-form-item>-->
<!--          </el-col>-->
<!--        </el-row>-->
        <el-form-item label="风险等级:" prop="phone" >
          <span>{{ state.form.riskLevel == 1 ? '重大' : state.form.riskLevel == 2?'较大': state.form.riskLevel == 3?'一般': state.form.riskLevel == 4 ? '低': ''}}</span>
        </el-form-item>
      </el-form>
      <div>
        <span style="font-size: 15px;font-weight: 700;">反馈意见:</span>
        <el-input v-model='state.form.feedBack' type="textarea" :rows="5" style="margin-top: 10px"></el-input>
      </div>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {listDept} from "@/api/system/dept";
import {listUser} from "@/api/system/user";
import {addTemplate, editTemplate} from "@/api/signAgreement/template";
import {addType, editType, getSignType} from "@/api/signAgreement/signType";
import {getInfo} from "@/api/login";
import {getToken} from "@/utils/auth";
import {verifyPhone} from "@/utils/validate";
import {pushWarning} from "@/api/company/warning";

const { proxy } = getCurrentInstance();
const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);

const state = reactive({
  form: {
    id: '',
    feedBack: '',

  },
  formRules:{
    feedBack: [{ required: true, trigger: "blur", message:'请输入反馈内容' }],
  },
})



const openDialog = async (type,value) => {
  if(type === 'edit') {
    state.form = JSON.parse(JSON.stringify(value))
  }
  dialogVisible.value = true;
}

const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(valid){
    if(!state.form.feedBack){
      ElMessage.warning('请输入反馈意见')
      return
    }
      const { ...data} = JSON.parse(JSON.stringify(state.form))
      const param = {
        id: data.id,
        feedBack: data.feedBack
      }
      const res = await pushWarning(param)
      if(res.code == 200){
        ElMessage({
          type: 'success',
          message: '提交成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")
}
const reset = () => {
  state.form = {
    id: '',
    feedBack: '',
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  :deep(.el-form-item__content) {
    width: 100%;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
  .custom-iframe {
    border: 1px solid #9b9999;
    /* 隐藏原生滚动条 */
    overflow: hidden;
  }
}
</style>
